
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

from __future__ import absolute_import
import json

version_json = '''
{
 "date": "2019-01-14T17:06:58+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "7a13b520c32559ef217ed431f2cc6e480f3a0aa0",
 "version": "2019.1.14"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
